@@ -1,9 +1,10 @@
-from typing import Any, Dict, List
+from __future__ import annotations
 
+from typing import Any, Dict, Iterable, Mapping, Sequence
+
+from di.api.dependencies import DependantBase, DependencyParameter
+from di.api.scopes import Scope
 from di.exceptions import ScopeViolationError, UnknownScopeError
-from di.types.dependencies import DependantBase
-from di.types.scopes import Scope
-from di.types.solved import SolvedDependant
 
 
 def check_is_inner(
@@ -26,15 +27,17 @@ def check_scope(dep: DependantBase[Any], scope_idxs: Dict[Scope, int]) -> None:
         )
 
 
-def validate_scopes(scopes: List[Scope], solved: SolvedDependant[Any]) -> None:
+def validate_scopes(
+    scopes: Sequence[Scope],
+    dag: Mapping[DependantBase[Any], Iterable[DependencyParameter]],
+) -> None:
     """Validate that dependencies all have a valid scope and
     that dependencies only depend on outer scopes or their own scope.
     """
-    scope_idxs = {scope: idx for idx, scope in enumerate(reversed(scopes + [None]))}
+    scope_idxs = {scope: idx for idx, scope in enumerate(reversed([*scopes, None]))}
 
-    for dep, params in solved.dag.items():
+    for dep, predecessors in dag.items():
         check_scope(dep, scope_idxs)
-        for param in params:
-            subdep = param.dependency
-            check_scope(subdep, scope_idxs)
-            check_is_inner(dep, subdep, scope_idxs)
+        for predecessor in predecessors:
+            check_scope(predecessor.dependency, scope_idxs)
+            check_is_inner(dep, predecessor.dependency, scope_idxs)
