@@ -16,9 +16,8 @@ else:
     from typing import Annotated, get_args, get_origin
 
 from di._utils.inspect import get_parameters, infer_call_from_annotation
-from di.exceptions import WiringError
-from di.types.dependencies import DependantBase, DependencyParameter, T
-from di.types.providers import (
+from di.api.dependencies import DependantBase, DependencyParameter, T
+from di.api.providers import (
     AsyncGeneratorProvider,
     CallableProvider,
     CoroutineProvider,
@@ -26,7 +25,8 @@ from di.types.providers import (
     DependencyType,
     GeneratorProvider,
 )
-from di.types.scopes import Scope
+from di.api.scopes import Scope
+from di.exceptions import WiringError
 
 _VARIABLE_PARAMETER_KINDS = (
     inspect.Parameter.VAR_POSITIONAL,
@@ -38,6 +38,7 @@ class Dependant(DependantBase[DependencyType]):
     wire: bool
     autowire: bool
     sync_to_thread: bool
+    __slots__ = ("wire", "autowire", "sync_to_thread", "dependencies", "overrides")
 
     @overload
     def __init__(
@@ -108,9 +109,7 @@ class Dependant(DependantBase[DependencyType]):
     ) -> None:
         self.call = call
         self.scope = scope
-        self.dependencies: Optional[
-            List[DependencyParameter[DependantBase[Any]]]
-        ] = None
+        self.dependencies: Optional[List[DependencyParameter]] = None
         self.share = share
         self.autowire = autowire
         self.wire = wire
@@ -138,7 +137,7 @@ class Dependant(DependantBase[DependencyType]):
 
     def get_dependencies(
         self,
-    ) -> List[DependencyParameter[DependantBase[Any]]]:
+    ) -> List[DependencyParameter]:
         """Collect all of the sub dependencies for this dependant
 
         For the Dependant implementation, this serves as a cache layer on
@@ -191,7 +190,7 @@ class Dependant(DependantBase[DependencyType]):
 
     def gather_dependencies(
         self,
-    ) -> List[DependencyParameter[DependantBase[Any]]]:
+    ) -> List[DependencyParameter]:
         """Collect this dependencies sub dependencies.
 
         The returned dict corresponds to keyword arguments that will be passed
@@ -202,7 +201,7 @@ class Dependant(DependantBase[DependencyType]):
         assert (
             self.call is not None
         ), "Container should have assigned call; this is a bug!"
-        res: List[DependencyParameter[DependantBase[Any]]] = []
+        res: List[DependencyParameter] = []
         for param in self.gather_parameters().values():
             sub_dependant: DependantBase[Any]
             if param.name in self.overrides:
@@ -260,7 +259,9 @@ class Dependant(DependantBase[DependencyType]):
 class JoinedDependant(DependantBase[DependencyType]):
     """A Dependant that aggregates other dependants without directly depending on them"""
 
-    _dependencies: Optional[List[DependencyParameter[Any]]]
+    __slots__ = ("dependant", "siblings", "_dependencies")
+
+    _dependencies: Optional[List[DependencyParameter]]
 
     def __init__(
         self,
@@ -275,7 +276,7 @@ class JoinedDependant(DependantBase[DependencyType]):
         self._dependencies = None
         self.share = dependant.share
 
-    def get_dependencies(self) -> List[DependencyParameter[DependantBase[Any]]]:
+    def get_dependencies(self) -> List[DependencyParameter]:
         """Get the dependencies of our main dependant and all siblings"""
         if self._dependencies is None:
             self._dependencies = list(
